## Python Package for Machine Learning Model LEOID (Level-based Ensemble for Overcoming Inbalanced Data)
\
More information about LEOID and example usage is available on Kaggle. [LEOID on Kaggle](https://www.kaggle.com/models/jayticku/leoid)
